import os
from random import randint
from quotly.Quote import Quote


class Quoty:
    def __init__(self):
        self.quotes = []
        self.quotes_file = 'data/quotes'

        if not os.path.exists('data'):
            os.mkdir('data')

        if os.path.exists('.env'):
            print('> Start reading existing quotes')
            self.read_quotes()

            print('> Finished reading existing quotes. Found {0} quotes!'.format(len(self.quotes)))
            print('> Quotly is ready for action!')

    def get_random(self):
        if len(self.quotes) > 0:
            return self.quotes[randint(0, len(self.quotes) - 1)]

        return Quote("Sorry! No quotes found :(")

    def write_quotes(self):
        with open(self.quotes_file, 'w') as file:
            for q in self.quotes:

                ts = ""
                for t in q.targets:
                    ts += '{0},'.format(t)

                file.write('{0};{1}'.format(q.quote, ts))

    def read_quotes(self):
        try:
            if os.path.isfile(self.quotes_file):
                with open(self.quotes_file, 'r') as file:
                    content = file.readlines()

                content = [x.strip() for x in content]
                for l in content:
                    q = l.split(';')[0]
                    targets = l.split(';')[1].split(',')

                    self.quotes.append(Quote(q, targets))
        except FileNotFoundError:
            print('> Unable to read quotes file!')



class Quote:
    def __init__(self, quote, *targets):
        self.quote = quote
        self.targets = []

        for t in targets:
            if len(t) > 0:
                self.targets.append(t[0])

    def has_target(self, target):
        return target in self.targets

    @staticmethod
    def filter_by_target(seq, target):
        for elem in seq:
            if target in elem.targets:
                yield elem

    @staticmethod
    def filter_by_targets(seq, targets):
        for elem in seq:
            if targets in elem.targets:
                yield elem



from dotenv import load_dotenv
from discord.ext import commands
from quotly.Quote import Quote
from quotly.Quoty import Quoty

load_dotenv()
quoty = Quoty()
quoty_bot = commands.Bot(command_prefix='!')

cmds = {
    'add_quote': 'quotly-add',
    'get_quote': 'quotly-get'
}


@quoty_bot.command(name=cmds['add_quote'])
async def create(ctx, q, *targets):
    quoty.quotes.append(Quote(q, targets))
    quoty.write_quotes()

    await ctx.send('New quote: \'{0}\'. Targets: {1}'.format(q, targets))


@quoty_bot.command(name=cmds['get_quote'])
async def quote(ctx, *targets):
    if not targets:
        await ctx.send(quoty.get_random().quote)


from setuptools import setup, find_packages

import quotly

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='quotly',
    version=quotly.__version__,
    packages=find_packages(exclude="web"),
    author='Schrotty',
    author_email='rubenmaurer@live.de',
    description='A quoting bot for the "Discord Hack Week"',
    long_description=long_description,
    long_description_content_type="text/markdown",
    include_package_data=True,
    license='MIT',
    keywords='discord discord-bot',
    url='https://github.com/Schrotty/quotly',
    install_requires=[
        'python-dotenv',
        'discord.py'
    ],
    classifiers=[
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)
